Module: Amazon::MWS::Feed

Includes:
Enumerations
Defined in:
lib/amazon/mws/feed.rb,
lib/amazon/mws/feed_enumerations.rb

Defined Under Namespace

Modules: Enumerations

Constant Summary

Constants included from Enumerations

Enumerations::FEED_TYPES, Enumerations::MESSAGE_TYPES

Instance Method Summary collapse

Instance Method Details

#cancel_feed_submissions(params = {}) ⇒ Object

SubmittedToDate The latest submission date you are looking for, in ISO8601 date format (for example, “2008-07-03T18:12:22Z” or “2008-07-03T18:12:22.093-07:00”).



182
183
184
185
186
187
# File 'lib/amazon/mws/feed.rb', line 182

def cancel_feed_submissions(params = {})
  response = 
  get("/", {"Action" => "CancelFeedSubmissions"}.merge(params))

  CancelFeedSubmissionsResponse.format(response)
end

#get_feed_submission_count(params = {}) ⇒ Object Also known as: feed_submission_count

SubmittedToDate The latest submission date you are looking for, in ISO8601 date format (for example, “2008-07-03T18:12:22Z” or “2008-07-03T18:12:22.093-07:00”).



139
140
141
142
143
144
# File 'lib/amazon/mws/feed.rb', line 139

def get_feed_submission_count(params = {})
  response = 
  get("/", {"Action" => "GetFeedSubmissionCount"}.merge(params))
  
  GetFeedSubmissionCountResponse.format(response)
end

#get_feed_submission_list(params = {}) ⇒ Object Also known as: feed_submission_list

SubmittedToDate The latest submission date you are looking for, in ISO8601 date format (for example, “2008-07-03T18:12:22Z” or “2008-07-03T18:12:22.093-07:00”).



79
80
81
82
83
84
# File 'lib/amazon/mws/feed.rb', line 79

def get_feed_submission_list(params = {})
 response = 
 get("/", {"Action" => "GetFeedSubmissionList"}.merge(params))
 
 result = GetFeedSubmissionListResponse.format(response)
end

#get_feed_submission_list_by_next_token(next_token) ⇒ Object Also known as: feed_submission_list_by_next_token

The GetFeedSubmissionListByNextToken operation returns a list of feed submissions that match the query parameters, using the NextToken, which was supplied by a previous call to either GetFeedSubmissionListByNextToken or a call to GetFeedSubmissionList, where the value of HasNext was true in that previous call.

Request Parameters


NextToken Token returned in a previous call to either GetFeedSubmissionList or GetFeedSubmissionListByNextToken when the value of HasNext was true.



99
100
101
102
103
104
105
106
107
# File 'lib/amazon/mws/feed.rb', line 99

def get_feed_submission_list_by_next_token(next_token)
  response = 
   get("/", {
     "Action"   => "GetFeedSubmissionListByNextToken", 
     "NextToken" => next_token
   })
   
   GetFeedSubmissionListByNextTokenResponse.format(response)
end

#get_feed_submission_result(feed_submission_id) ⇒ Object Also known as: feed_submission_result

FeedSubmissionId The identifier of the feed submission to get results for. Obtained by a call to GetFeedSubmissionList.



206
207
208
209
210
211
212
213
214
# File 'lib/amazon/mws/feed.rb', line 206

def get_feed_submission_result(feed_submission_id)
  response = 
  get("/", {
    "Action"           => "GetFeedSubmissionResult", 
    "FeedSubmissionId" => feed_submission_id
  }.merge(params))

  GetFeedSubmissionResultResponse.format(response)
end

#submit_feed(feed_type, message_type, message = {}) ⇒ Object Also known as: submit

Amazon MWS limits calls to 1,000 total calls per hour per seller account. For best performance, you should limit your calls to SubmitFeed to no more than three feeds per hour per seller account, although you can successfully call SubmitFeed up to 30 times per hour. Feed size is limited to 2,147,483,647 bytes (2^32 -1) per feed.

Raises:



17
18
19
20
21
22
23
24
25
26
27
28
29
30
# File 'lib/amazon/mws/feed.rb', line 17

def submit_feed(feed_type, message_type, message = {})
  message_type= message_type.to_s.camelize
  raise InvalidMessageType if !MESSAGE_TYPES.include?(message_type)
  
  body = Amazon::MWS::FeedBuilder.new(message_type, message)
  
  response = 
  post("/", {
    "Action"   => "SubmitFeed", 
    "FeedType" => FEED_TYPES[feed_type]
  }, body)

  result = SubmitFeedResponse.format(response)
end